@@ -50,7 +50,7 @@ def openLocked(filename, perms, create = True):
     #TODO: put section delimiters as separating element of the list
     #      so that we can process multiple sections in one go
     #TODO: add a comment all but provided options as a section option
-class IPAChangeConf:
+class IPAChangeConf(object):
 
     def __init__(self, name):
         self.progname = name
@@ -151,6 +151,13 @@ class IPAChangeConf:
             return section
         return self.sectnamdel[0]+section+self.sectnamdel[1]+self.deol
 
+    @staticmethod
+    def _get_debug_level_val(value):
+        if value > 16:
+            value = hex(value)
+
+        return value
+
     def dump(self, options, level=0):
         output = ""
         if level >= len(self.indent):
